FileModifier class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
Static Methods
-
addAssetToPubspec(String assetPath)
→ Future<void>
-
-
addImports(String filePath, List<String> imports)
→ Future<void>
-
-
addRoute({required String routesFilePath, required String appRouterFilePath, required String routeName, required String routePath, required String screenWidget, required String cubit})
→ Future<void>
-
-
checkFileExistenceAsync({required String filePath})
→ Future<bool>
-
-
checkFolderExistenceAsync({required String folderPath})
→ Future<bool>
-
-
createFolder(String folderPath)
→ Future<void>
-
-
getProjectName()
→ String
-
-
isFlutterProjectRoot()
→ Future<bool>
-
-
recreatePubspec()
→ Future<void>
-
-
replaceFileContent({required String filePath, required String newContent, bool createIfNotExists = false})
→ Future<void>
-
-
resolveExecutable(String name)
→ String
-
-
runBuildRunner({bool showResult = true})
→ Future<void>
-
-
runPubGet({bool showResult = true})
→ Future<void>
-
-
runPubOutdated({bool showResult = true})
→ Future<void>
-
-
runPubUpgrade({bool showResult = true})
→ Future<void>
-
-
setupEnvFile()
→ Future<void>
-
-
updateMainDiFile({required String featureName, required String packageName, String? ownFeaturesName, bool? isSub = false})
→ Future<void>
-